<?php 
require_once "conexion.php";
class ModeloAdministrador extends ModeloConexion{

	/*===========================================================================
	CONSULTA ADMINISTRADOR
	===========================================================================*/
	protected function mdlConsultaAdministrador($usuario){

		$query = "SELECT * FROM sie_usuarios WHERE correo = :correo";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->bindParam(":correo", $usuario);

		$sql->execute();

		return $sql;

	}

	/*===========================================================================
	CONSULTA ADMINISTRADOR (Prueba)
	===========================================================================*/
	protected function mdlConsultaAdministradorHash(){

		$query = "SELECT * FROM sie_usuarios";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	
	protected function mdlRegistraEstadoSesion($usuario, $fecha_hora_actual){


		$query = "UPDATE sie_usuarios SET sesion_activa = 1, fecha_ultimo_inicio_sesion = '$fecha_hora_actual' WHERE correo = '$usuario'";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	/*===========================================================================
	RESTABLECE CONTRASEÑA
	===========================================================================*/
	protected function mdlRestableceContrasena($clave, $correo){

		$query = "UPDATE sie_usuarios SET contrasena = '$clave' WHERE correo = '$correo'";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	/*===========================================================================
	CONSULTA CÓDIGOS
	===========================================================================*/
	protected function mdlConsultaCodigos(){

		$query = "SELECT * FROM sie_enlaces";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	/*===========================================================================
	CONSULTA CÓDIGO UNICO
	===========================================================================*/
	protected function mdlConsultaCodigo($codigo, $correo){

		$query = "SELECT * FROM sie_enlaces WHERE codigo = '$codigo' AND correo_hash= '$correo'";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	protected function mdlRegistraCodigo($codigo, $correo){

		$query = "INSERT INTO sie_enlaces (codigo, estado, correo_hash) VALUES ('$codigo', 1, '$correo')";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	protected function mdlActualizaEnlace($codigo){

		$query = "UPDATE sie_enlaces SET estado = 2 WHERE codigo = '$codigo'";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	/*====================================================================
	CONSULTA PROCESO
	=====================================================================*/
	protected function mdlConsultaProcesos($id_proceso){

		$query = "SELECT * FROM sie_procesos WHERE id = '$id_proceso'";

		$sql = ModeloConexion::conectardb()->prepare($query);

		$sql->execute();

		return $sql;

	}

	// public function mdlEncription($string){
	// 	$output = FALSE;
	// 	$key = hash('sha256', SECRET_KEY);
	// 	$iv = substr(hash('sha256', SECRET_IV), 0, 16);
	// 	$output=openssl_encrypt($string, METHOD, $key, 0, $iv);
	// 	$output=base64_decode($output);
	// 	return $output;
	// }

	// public function mdlDencription($string){
	// 	$key=hash('sha256', SECRET_KEY);
	// 	$iv=substr(hash('sha256', SECRET_IV), 0, 16);
	// 	$output=openssl_decrypt(base64_decode($string), METHOD, $key, 0, $iv);
	// 	return $output;
	// }


}


// Peticiones ajax POST
// if(isset($_POST['accion'])){

	// if($_POST['accion'] == "iniciar_sesion"){
		// echo "prueba";
	// }

// }

